@@ -92,7 +92,7 @@ def minify(in_file, out_file = None, verbose=False):
     console.confirm('  %s ( Reduction : %.1f%% )' % (out_file, (float(org_size - new_size) / org_size * 100)))
 
 
-def jslint(files, fix = False, relax = False, fail = False):
+def jslint(files, fix = False, relax = False, fail = True):
     files = FileList.check(files)
 
     options = []
